#
# spec file for package lxqt-archiver
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-archiver
Version:        0.8.0
Release:        1.2
Summary:        LXQt File Archiver
License:        GPL-2.0-or-later
Group:          System/GUI/LXQt
URL:            http://www.lxqt.org
Source0:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  libexif-devel
BuildRequires:  libqt5-linguist-devel
BuildRequires:  lxqt-build-tools-devel >= 0.13.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.15.0
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libfm-qt) >= 1.3.0
Requires:       bsdtar
Requires(post): desktop-file-utils
Requires(pre):  desktop-file-utils

%description
LXQt file archiver.

%lang_package

%prep
%setup -q

%build
%cmake

%install
%cmake_install

%find_lang %{name} --with-qt

%files
%license LICENSE
%doc AUTHORS CHANGELOG README.md
%{_bindir}/lxqt-archiver
%{_datadir}/applications/lxqt-archiver.desktop
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/scalable/
%dir %{_datadir}/icons/hicolor/scalable/apps/
%{_datadir}/icons/hicolor/scalable/apps/lxqt-archiver.svg

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt-archiver/
%dir %{_datadir}/lxqt-archiver/translations/
%{_datadir}/lxqt-archiver/translations/*.qm

%changelog
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Updated translations and dependencies and bumped the version
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 0.7.0:
  * Removed the redundant function `n_fields()` from `glib-utils`.
  * Silenced some compilation warnings.
* Thu Apr 28 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  * Allow changing of the view icon size and remember it.
  * Allow sorting by any column (but only sort by the first column at startup).
  * Forget the password (if any) on reloading the archive.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  * Show password prompt for archives with encrypted lists.
  * Fixed listing RAR archive contents with encrypted file list.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  * Disk images can be opened and extracted.
  * Window settings are remembered.
  * The directory view is made horizontally scrollable.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.3.0:
  * Avoid memory leak in "java-utils.c".
  * Fixed comparison of integer expressions of different signedness.
  * Removed "g_ptr_array_free_full" from "glib-utils.c" and used
    GLib's "g_ptr_array_free" instead.
  * Use bsdtar to handle RPM packages.
* Mon Jun 29 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Revert BuildRequires hicolor-icon-theme for icon dirs
* Wed Jun 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Use libexecdir macro to fix errors in Factory
- BuildRequires hicolor-icon-theme for icon dirs
* Mon May 18 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Removed Recommends lxqt-archiver-lang due to auto supplements
* Sun May 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.2.0:
  * Added an icon for the app.
  * Prevent the contents of an extracted archive from being mixed
    with other files if overwriting isn't chosen.
  * Added expand and collapse actions.
  * Fixed build with GCC 10.
  * Required json-glib as a dependency.
- Remove lxqt-archiver.desktop:
  use upstream desktop file. It has its own icon now.
  See https://github.com/lxqt/lxqt-archiver/issues/157
* Fri May 15 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixed sources and added keyring
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Removed lxqt-archiver-execdir.patch: contained in upstream
- Update to version 0.1.1
  * Removed the unused qtdbus dependency.
  * Used 'LIBEXECDIR' instead of 'LIBDIR' for internal executables.
  * Fixed handling of RPM archives.
* Wed Apr 22 2020 Michael Vetter <mvetter@suse.com>
- Add lxqt-archiver-execdir.patch: install in helper programs
  in libexecdir not libdir
* Wed Apr 22 2020 Michael Vetter <mvetter@suse.com>
- Create package 0.1.0 for openSUSE
